@@ -21,6 +21,7 @@ import zlib
 from .config import ConfigObject
 from .statusbar import StatusBar
 from .utils import (
+    FileOps,
     readJson,
     writeJson,
 )
@@ -56,6 +57,7 @@ class FileScanner:
         self.ignored_toplevel_folders = list(set([config.archive_dir, config.log_dir, config.trash_dir, config.config_dir]))
         self.force_posix_path_sep = config.force_posix_path_sep
         self.write_database_x2 = config.write_database_x2 and not config.scan_only
+        self.follow_symlinks = not config.nofollow
         # Init other variables
         self.dir = directory_root_path
         self.other_dir = other_root_path
@@ -148,14 +150,23 @@ class FileScanner:
 
     def calcCrc(self, file_path: str, prev: int = 0) -> str:
         try:
-            with open(file_path, "rb") as f:
-                for line in f:
-                    prev = zlib.crc32(line, prev)
-            return "%X" % (prev & 0xFFFFFFFF)
+            if self.follow_symlinks or not FileOps.islink(file_path):
+                with FileOps.open(file_path) as f:
+                    for line in f:
+                        prev = zlib.crc32(line, prev)
+                return "%X" % (prev & 0xFFFFFFFF)
+            else:
+                return self.symlinkCrc(file_path)
         except Exception:
             # file either removed by user, or another program such as antimalware (using realtime monitoring) during scan, or lack permissions
             raise Exception("Exiting, error trying to read file: " + file_path)
 
+    def symlinkCrc(self, file_path: str) -> str:
+        if FileOps.islink(file_path):
+            crc = zlib.crc32(FileOps.readlink(file_path).encode())
+            return "%X" % (crc & 0xFFFFFFFF)
+        return "0"
+
     def timeMatch(self, t1: float, t2: float, exact_only: bool = False, tz_diffs: list = [3600, 3601, 3602], fs_tol: int = 2) -> bool:
         if t1 == t2:
             return True
@@ -169,13 +180,13 @@ class FileScanner:
 
     def pathMatch(self, path: str, path_list: list) -> bool:
         # is path in path_list (or a subdir of one in it)
-        if os.path.isabs(path):
+        if FileOps.isabs(path):
             relpath, _abspath = os.path.relpath(path, self.dir), path
         else:
             relpath, _abspath = path, os.path.join(self.dir, path)
         for p in path_list:
             p = os.path.normcase(p)
-            if os.path.isabs(p):
+            if FileOps.isabs(p):
                 raise Exception("Default .backupy dirs have been changed to absolute paths in the config, they should be relative paths.")
                 # if os.path.normcase(os.path.commonpath([p, abspath])) == p:
                 #     return True
@@ -199,12 +210,12 @@ class FileScanner:
 
     def scanDir(self, stdout_status_bar: bool) -> None:
         # init
-        if os.path.isdir(self.dir) and self.dict_current == {}:
-            total = sum(len(f) for r, d, f in os.walk(self.dir))
+        if FileOps.isdir(self.dir) and self.dict_current == {}:
+            total = sum(len(f) for r, d, f in FileOps.walk(self.dir))
             scan_status = StatusBar("Scanning", total, stdout_status_bar, gui=self.gui)
             # will never enable followlinks, adds too many possible issues and complexity in handling them
             # may add notification if backupy encounters a directory it cannot access (likely due to permissions)
-            for dir_path, subdir_list, file_list in os.walk(self.dir, onerror=None, followlinks=False):
+            for dir_path, subdir_list, file_list in FileOps.walk(self.dir, onerror=None, followlinks=False):
                 # ignore folders
                 if self.pathMatch(dir_path, self.ignored_toplevel_folders):
                     subdir_list.clear()
@@ -220,12 +231,12 @@ class FileScanner:
                 for subdir in subdir_list:
                     full_path = os.path.join(dir_path, subdir)
                     try:
-                        if len(os.listdir(full_path)) == 0:
+                        if len(FileOps.listdir(full_path)) == 0 or FileOps.islink(full_path):
                             # track empty directories with a dummy entry, non-empty directories should not have entries, they are handled automatically by having files inside them
                             relative_path = os.path.relpath(full_path, self.dir)
                             if self.force_posix_path_sep:
                                 relative_path = relative_path.replace(os.path.sep, "/")
-                            self.dict_current[relative_path] = {"size": 0, "mtime": 0, "crc": "0", "dir": True}
+                            self.dict_current[relative_path] = {"size": 0, "mtime": 0, "crc": self.symlinkCrc(full_path), "dir": True}
                             self.set_dirs.add(relative_path)
                     except Exception as e:
                         raise Exception("%s %s for directory: %s" % (type(e).__name__, str(e.args), full_path))
@@ -246,8 +257,9 @@ class FileScanner:
 
     def scanFile(self, full_path: str, relative_path: str) -> None:
         # get file attributes and create entry
-        size = os.path.getsize(full_path)
-        mtime = os.path.getmtime(full_path)
+        stat = FileOps.stat(full_path, follow_symlinks=self.follow_symlinks)
+        size = stat.st_size
+        mtime = stat.st_mtime
         self.dict_current[relative_path] = {"size": size, "mtime": mtime}
         if self.compare_mode == "crc":
             self.dict_current[relative_path]["crc"] = self.calcCrc(full_path)
