@@ -16,11 +16,12 @@
 import csv
 import json
 import os
+import shutil
 import unicodedata
 
 
 def getVersion() -> str:
-    return "1.9.2"
+    return "1.9.4"
 
 
 def getString(text: str) -> str:
@@ -82,6 +83,29 @@ def writeJson(file_path: str, data: dict, subdir: bool = True, sort_keys: bool =
         print(getString("Error, could not write: ") + file_path)
 
 
+class FileOps:
+    """expose file operation functions as class attributes for easy monkey-patching"""
+    # functions for readonly operations (used in BackupManager, FileManager, or FileScanner)
+    abspath = os.path.abspath
+    isabs = os.path.isabs
+    isdir = os.path.isdir
+    islink = os.path.islink
+    listdir = os.listdir
+    open = lambda path: open(path, "rb")
+    readlink = os.readlink
+    stat = os.stat
+    walk = os.walk
+    # functions for read/write operations (only used in FileManager)
+    chmod = os.chmod
+    copy = shutil.copy2
+    copyff = lambda source, dest: shutil.copy2(source, dest, follow_symlinks=False)
+    makedirs = os.makedirs
+    move = shutil.move
+    remove = os.remove
+    removedirs = os.removedirs
+    rmdir = os.rmdir
+
+
 def testConsistency(source_dicts: tuple, source_sets: tuple,
                     dest_dicts: tuple, dest_sets: tuple,
                     transfer_lists: tuple,
